package trapmon;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.*;

// ============================================================================
/**
 * JTable for displaying non-trap SNMP messages.
 * Description and comments to follow.
 *
 */
public class JMessageTable extends JTable
{
    protected Vector messages;
    protected MessageTableModel model;

    // ------------------------------------------------------------ constructor
    /**
     * Create the table.
     *
     */
    public JMessageTable( ) {
        Vector data,
               columns;

        messages = new Vector();

        columns = new Vector( 3 );
        columns.addElement("Community");
        columns.addElement("Originator Address");
        columns.addElement("Message Type");
        columns.addElement("Request ID");
        data = new Vector();
        
        model = new MessageTableModel( data, columns );
        this.setModel( model );
        this.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );
        this.setShowHorizontalLines( false );
        this.setAutoResizeMode( AUTO_RESIZE_LAST_COLUMN );

    } // ----------------------------------------------------------------------


    // ------------------------------------------------------------------------
    /**
     * Add a message entry to the end of the table.
     *
     */
    public void addMessage( SnmpMessage message ) {
        Vector row = new Vector( 4 );
        String messageType;
        
        row.addElement( message.community );

        row.addElement( message.originator.getHostAddress() );
        row.addElement( message.messageName );
        row.addElement( Long.toString( message.requestID ));
        
        model.addRow( row );
        model.fireTableDataChanged();
        
        messages.addElement( message );
    } // ----------------------------------------------------------------------


    // ------------------------------------------------------------------------
    /**
     * Return the SnmpMessage object for the currently-selected table entry.
     *
     */
    public SnmpMessage getSelectedMessage( ) {
        SnmpMessage message;
        int rowNumber;
        
        if ( messages.size() == 0 ) return ( null );
        rowNumber = this.getSelectedRow();
        if ( rowNumber < 0 )
            message = null;
        else
            message = (SnmpMessage) messages.elementAt( rowNumber );

        return ( message );            
    } // ----------------------------------------------------------------------


    // ------------------------------------------------------------------------
    /**
     * Clear the table.  This includes emptying the table data, the 
     * corresponding array of message objects, and refreshing the display.
     *
     */
    public void clearTable( ) {
        messages   = new Vector();
        model.data = new Vector();
        model.fireTableDataChanged();
    } // ----------------------------------------------------------------------

} // ==========================================================================




// ============================================================================
/**
 *  Class which holds and manipulates the table data.
 *
 */
class MessageTableModel extends AbstractTableModel
{
    Vector data;
    Vector headers;

    // ------------------------------------------------------------ constructor
    public MessageTableModel( Vector entries, Vector columns ) {
        data = entries;
        headers = columns;
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public int getRowCount() {
        if ( data == null ) return 0;
        else return data.size();
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public int getColumnCount() { 
        return headers.size(); 
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public Object getValueAt( int r, int c ) {
        if (( data == null ) || ( r >= data.size() )) return null;
        else return ((Vector)data.elementAt( r )).elementAt( c );
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public String getColumnName( int c ) {
        return ((String)headers.elementAt( c ));
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public void addRow( Vector row ) {
        data.addElement( row );
    } // ----------------------------------------------------------------------
    
} // ==========================================================================

