package trapmon;

import java.awt.*;
import java.awt.event.*;
import java.awt.print.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.*;

// ============================================================================
/**
 * JTable for displaying SNMP traps.
 * Description and comments to follow.
 *
 */
public class JTrapTable extends JTable
{
    protected Vector messages;
    protected TrapTableModel model;


    // ------------------------------------------------------------ constructor
    /**
     * Create the table.
     *
     */
    public JTrapTable( ) {
        Vector data,
               columns;

        messages = new Vector();

        columns = new Vector( 4 );
        columns.addElement("Community");
        columns.addElement("Agent Address");
        columns.addElement("Enterprise");
        columns.addElement("Trap Type");
        data = new Vector();
        
        model = new TrapTableModel( data, columns );
        this.setModel( model );
        this.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );
        this.setShowHorizontalLines( false );
        this.setAutoResizeMode( AUTO_RESIZE_LAST_COLUMN );

    } // ----------------------------------------------------------------------


    // ------------------------------------------------------------------------
    /**
     * Add a message entry to the end of the table.
     *
     */
    public void addMessage( SnmpMessage message ) {
        Vector row = new Vector( 4 );
        String messageType;
        
        row.addElement( message.community );
        row.addElement( message.agentAddress );
        row.addElement( message.textualOID );
        row.addElement( message.genericTrapName );
        
        model.addRow( row );
        model.fireTableDataChanged();
        
        messages.addElement( message );
    } // ----------------------------------------------------------------------


    // ------------------------------------------------------------------------
    /**
     * Return the SnmpMessage object for the currently-selected table entry.
     *
     */
    public SnmpMessage getSelectedMessage( ) {
        SnmpMessage message;
        int rowNumber;
        
        if ( messages.size() == 0 ) return ( null );
        rowNumber = this.getSelectedRow();
        if ( rowNumber < 0 )
            message = null;
        else
            message = (SnmpMessage) messages.elementAt( rowNumber );

        return ( message );            
    } // ----------------------------------------------------------------------


    // ------------------------------------------------------------------------
    /**
     * Clear the table.  This includes emptying the table data, the 
     * corresponding array of message objects, and refreshing the display.
     *
     */
    public void clearTable( ) {
        messages   = new Vector();
        model.data = new Vector();
        model.fireTableDataChanged();
    } // ----------------------------------------------------------------------

} // ==========================================================================




// ============================================================================
/**
 *  Class which holds and manipulates the table data.
 *
 */
class TrapTableModel extends AbstractTableModel
{
    Vector data;
    Vector headers;

    // ------------------------------------------------------------ constructor
    public TrapTableModel( Vector entries, Vector columns ) {
        data = entries;
        headers = columns;
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public int getRowCount() {
        if ( data == null ) return 0;
        else return data.size();
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public int getColumnCount() { 
        return headers.size(); 
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public Object getValueAt( int r, int c ) {
        if (( data == null ) || ( r >= data.size() )) return null;
        else return ((Vector)data.elementAt( r )).elementAt( c );
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public String getColumnName( int c ) {
        return ((String)headers.elementAt( c ));
    } // ----------------------------------------------------------------------

    // ------------------------------------------------------------------------
    public void addRow( Vector row ) {
        data.addElement( row );
    } // ----------------------------------------------------------------------
    
} // ==========================================================================

